@@ -3,7 +3,7 @@
  * Copyright (C) 2007, 2008 Alp Toker <alp@atoker.com>
  * Copyright (C) 2008 Collabora Ltd.
  * Copyright (C) 2011, 2017 Igalia S.L.
- * Portions Copyright (c) 2011 Motorola Mobility, Inc.  All rights reserved.
+ * Portions Copyright (c) 2011 Motorola Mobility, Inc. All rights reserved.
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public
@@ -21,7 +21,7 @@
  * Boston, MA 02110-1301, USA.
  */
 
-#if !defined(__WEBKIT_H_INSIDE__) && !defined(WEBKIT2_COMPILATION)
+#if !defined(__WEBKIT_H_INSIDE__) && !defined(BUILDING_WEBKIT)
 #error "Only <wpe/webkit.h> can be included directly."
 #endif
 
@@ -30,7 +30,6 @@
 
 #include <wpe/WebKitAuthenticationRequest.h>
 #include <wpe/WebKitBackForwardList.h>
-#include <wpe/WebKitColor.h>
 #include <wpe/WebKitContextMenu.h>
 #include <wpe/WebKitDefines.h>
 #include <wpe/WebKitEditorState.h>
@@ -39,13 +38,12 @@
 #include <wpe/WebKitFormSubmissionRequest.h>
 #include <wpe/WebKitHitTestResult.h>
 #include <wpe/WebKitInputMethodContext.h>
-#include <wpe/WebKitJavascriptResult.h>
 #include <wpe/WebKitNavigationAction.h>
 #include <wpe/WebKitNotification.h>
 #include <wpe/WebKitOptionMenu.h>
 #include <wpe/WebKitPermissionRequest.h>
+#include <wpe/WebKitPermissionStateQuery.h>
 #include <wpe/WebKitPolicyDecision.h>
-#include <wpe/WebKitRectangle.h>
 #include <wpe/WebKitScriptDialog.h>
 #include <wpe/WebKitSettings.h>
 #include <wpe/WebKitURIRequest.h>
@@ -53,23 +51,24 @@
 #include <wpe/WebKitUserMessage.h>
 #include <wpe/WebKitWebContext.h>
 #include <wpe/WebKitWebResource.h>
-#include <wpe/WebKitWebsitePolicies.h>
-#include <wpe/WebKitWebViewBackend.h>
 #include <wpe/WebKitWebViewSessionState.h>
+#include <wpe/WebKitWebsitePolicies.h>
 #include <wpe/WebKitWindowProperties.h>
 
+#include <wpe/WebKitNetworkSession.h>
+
+#include <wpe/WebKitColor.h>
+#include <wpe/WebKitRectangle.h>
+#include <wpe/WebKitWebViewBackend.h>
+#include <wpe/wpe-platform.h>
+
 G_BEGIN_DECLS
 
 #define WEBKIT_TYPE_WEB_VIEW            (webkit_web_view_get_type())
-#define WEBKIT_WEB_VIEW(obj)            (G_TYPE_CHECK_INSTANCE_CAST((obj), WEBKIT_TYPE_WEB_VIEW, WebKitWebView))
-#define WEBKIT_IS_WEB_VIEW(obj)         (G_TYPE_CHECK_INSTANCE_TYPE((obj), WEBKIT_TYPE_WEB_VIEW))
-#define WEBKIT_WEB_VIEW_CLASS(klass)    (G_TYPE_CHECK_CLASS_CAST((klass),  WEBKIT_TYPE_WEB_VIEW, WebKitWebViewClass))
-#define WEBKIT_IS_WEB_VIEW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE((klass),  WEBKIT_TYPE_WEB_VIEW))
-#define WEBKIT_WEB_VIEW_GET_CLASS(obj)  (G_TYPE_INSTANCE_GET_CLASS((obj),  WEBKIT_TYPE_WEB_VIEW, WebKitWebViewClass))
 
-typedef struct _WebKitWebView        WebKitWebView;
-typedef struct _WebKitWebViewClass   WebKitWebViewClass;
-typedef struct _WebKitWebViewPrivate WebKitWebViewPrivate;
+WEBKIT_DECLARE_DERIVABLE_TYPE (WebKitWebView, webkit_web_view, WEBKIT, WEB_VIEW, GObject)
+
+typedef struct _WebKitPrintOperation WebKitPrintOperation;
 
 /**
  * WebKitPolicyDecisionType:
@@ -85,7 +84,7 @@ typedef struct _WebKitWebViewPrivate WebKitWebViewPrivate;
  *   a #WebKitNavigationPolicyDecision. These decisions are useful for implementing
  *   special actions for new windows, such as forcing the new window to open
  *   in a tab when a keyboard modifier is active or handling a special
- *   target attribute on &lt;a&gt; elements.
+ *   target attribute on <a> elements.
  * @WEBKIT_POLICY_DECISION_TYPE_RESPONSE: This type of decision is used when WebKit has
  *   received a response for a network resource and is about to start the load.
  *   Note that these resources include all subresources of a page such as images
@@ -150,18 +149,23 @@ typedef enum {
  * detected by trying to display any kind of resource (e.g. an image)
  * from an untrusted source.
  *
- * Enum values used to denote the different events which can trigger
- * the detection of insecure content.
+ * Enum values previously used to denote the different events which can trigger
+ * the detection of insecure content. Since 2.46, WebKit generally no longer
+ * loads insecure content in secure contexts.
+ *
+ * Deprecated: 2.46
  */
 typedef enum {
     WEBKIT_INSECURE_CONTENT_RUN,
     WEBKIT_INSECURE_CONTENT_DISPLAYED
 } WebKitInsecureContentEvent;
 
+
 /**
  * WebKitWebProcessTerminationReason:
  * @WEBKIT_WEB_PROCESS_CRASHED: the web process crashed.
  * @WEBKIT_WEB_PROCESS_EXCEEDED_MEMORY_LIMIT: the web process exceeded the memory limit.
+ * @WEBKIT_WEB_PROCESS_TERMINATED_BY_API: the web process termination was requested by an API call. Since: 2.34
  *
  * Enum values used to specify the reason why the web process terminated abnormally.
  *
@@ -169,124 +173,179 @@ typedef enum {
  */
 typedef enum {
     WEBKIT_WEB_PROCESS_CRASHED,
-    WEBKIT_WEB_PROCESS_EXCEEDED_MEMORY_LIMIT
+    WEBKIT_WEB_PROCESS_EXCEEDED_MEMORY_LIMIT,
+    WEBKIT_WEB_PROCESS_TERMINATED_BY_API
 } WebKitWebProcessTerminationReason;
 
+/**
+ * WebKitMediaCaptureState:
+ * @WEBKIT_MEDIA_CAPTURE_STATE_NONE: Media capture is disabled.
+ * @WEBKIT_MEDIA_CAPTURE_STATE_ACTIVE: Media capture is active.
+ * @WEBKIT_MEDIA_CAPTURE_STATE_MUTED: Media capture is muted.
+ *
+ * Enum values used to specify the capture state of a media device.
+ *
+ * Since: 2.34
+ */
+typedef enum {
+    WEBKIT_MEDIA_CAPTURE_STATE_NONE,
+    WEBKIT_MEDIA_CAPTURE_STATE_ACTIVE,
+    WEBKIT_MEDIA_CAPTURE_STATE_MUTED,
+} WebKitMediaCaptureState;
+
+/**
+ * WebKitWebExtensionMode:
+ * @WEBKIT_WEB_EXTENSION_MODE_NONE: Not for an extension.
+ * @WEBKIT_WEB_EXTENSION_MODE_MANIFESTV2: For a ManifestV2 extension.
+ * @WEBKIT_WEB_EXTENSION_MODE_MANIFESTV3: For a ManifestV3 extension.
+ *
+ * Enum values used for setting if a #WebKitWebView is intended for
+ * WebExtensions.
+ *
+ * Since: 2.38
+ */
+typedef enum {
+    WEBKIT_WEB_EXTENSION_MODE_NONE,
+    WEBKIT_WEB_EXTENSION_MODE_MANIFESTV2,
+    WEBKIT_WEB_EXTENSION_MODE_MANIFESTV3,
+} WebKitWebExtensionMode;
+
 /**
  * WebKitFrameDisplayedCallback:
  * @web_view: a #WebKitWebView
  * @user_data: user data
  *
- * Callback to be called when a frame is displayed in a #webKitWebView.
+ * Callback to be called when a frame is displayed in a #WebKitWebView.
  *
  * Since: 2.24
  */
 typedef void (* WebKitFrameDisplayedCallback) (WebKitWebView *web_view,
                                                gpointer       user_data);
 
-struct _WebKitWebView {
-    GObject parent;
-
-    /*< private >*/
-    WebKitWebViewPrivate *priv;
-};
-
 struct _WebKitWebViewClass {
     GObjectClass parent;
 
-    void           (* load_changed)                (WebKitWebView               *web_view,
-                                                    WebKitLoadEvent              load_event);
-    gboolean       (* load_failed)                 (WebKitWebView               *web_view,
-                                                    WebKitLoadEvent              load_event,
-                                                    const gchar                 *failing_uri,
-                                                    GError                      *error);
+    /*< public >*/
+    void       (* load_changed)                (WebKitWebView               *web_view,
+                                                WebKitLoadEvent              load_event);
+    gboolean   (* load_failed)                 (WebKitWebView               *web_view,
+                                                WebKitLoadEvent              load_event,
+                                                const gchar                 *failing_uri,
+                                                GError                      *error);
 
-    WebKitWebView *(* create)                      (WebKitWebView               *web_view,
-                                                    WebKitNavigationAction      *navigation_action);
-    void           (* ready_to_show)               (WebKitWebView               *web_view);
-    void           (* run_as_modal)                (WebKitWebView               *web_view);
-    void           (* close)                       (WebKitWebView               *web_view);
+    WebKitWebView *(* create)                  (WebKitWebView               *web_view,
+                                                WebKitNavigationAction      *navigation_action);
 
-    gboolean       (* script_dialog)               (WebKitWebView               *web_view,
-                                                    WebKitScriptDialog          *dialog);
+    void       (* ready_to_show)               (WebKitWebView               *web_view);
+    void       (* run_as_modal)                (WebKitWebView               *web_view);
+    void       (* close)                       (WebKitWebView               *web_view);
 
-    gboolean       (* decide_policy)               (WebKitWebView               *web_view,
-                                                    WebKitPolicyDecision        *decision,
-                                                    WebKitPolicyDecisionType     type);
-    gboolean       (* permission_request)          (WebKitWebView               *web_view,
-                                                    WebKitPermissionRequest     *permission_request);
-    void           (* mouse_target_changed)        (WebKitWebView               *web_view,
-                                                    WebKitHitTestResult         *hit_test_result,
-                                                    guint                        modifiers);
-    void           (* resource_load_started)       (WebKitWebView               *web_view,
-                                                    WebKitWebResource           *resource,
-                                                    WebKitURIRequest            *request);
-    gboolean       (* enter_fullscreen)            (WebKitWebView               *web_view);
-    gboolean       (* leave_fullscreen)            (WebKitWebView               *web_view);
-    gboolean       (* run_file_chooser)            (WebKitWebView               *web_view,
-                                                    WebKitFileChooserRequest    *request);
-    gboolean       (* context_menu)                (WebKitWebView               *web_view,
-                                                    WebKitContextMenu           *context_menu,
-                                                    void                        *event, /* FIXME: Use a wpe thing here. I'm not sure we want to expose libwpe in the API. */
-                                                    WebKitHitTestResult         *hit_test_result);
-    void           (* context_menu_dismissed)      (WebKitWebView               *web_view);
-    void           (* submit_form)                 (WebKitWebView               *web_view,
-                                                    WebKitFormSubmissionRequest *request);
-    void           (* insecure_content_detected)   (WebKitWebView               *web_view,
-                                                    WebKitInsecureContentEvent   event);
-    gboolean       (* web_process_crashed)         (WebKitWebView               *web_view);
+    gboolean   (* script_dialog)               (WebKitWebView               *web_view,
+                                                WebKitScriptDialog          *dialog)  ;
 
-    gboolean       (* authenticate)                (WebKitWebView               *web_view,
-                                                    WebKitAuthenticationRequest *request);
-    gboolean       (* load_failed_with_tls_errors) (WebKitWebView               *web_view,
-                                                    const gchar                 *failing_uri,
-                                                    GTlsCertificate             *certificate,
-                                                    GTlsCertificateFlags         errors);
-    gboolean       (* show_notification)           (WebKitWebView               *web_view,
-                                                    WebKitNotification          *notification);
-    void           (* web_process_terminated)      (WebKitWebView               *web_view,
-                                                    WebKitWebProcessTerminationReason reason);
-    gboolean       (* user_message_received)       (WebKitWebView               *web_view,
-                                                    WebKitUserMessage           *message);
-    gboolean       (* show_option_menu)            (WebKitWebView               *web_view,
-                                                    WebKitOptionMenu            *menu,
-                                                    WebKitRectangle             *rectangle);
+    gboolean   (* decide_policy)               (WebKitWebView               *web_view,
+                                                WebKitPolicyDecision        *decision,
+                                                WebKitPolicyDecisionType     type);
+    gboolean   (* permission_request)          (WebKitWebView               *web_view,
+                                                WebKitPermissionRequest     *permission_request);
+    void       (* mouse_target_changed)        (WebKitWebView               *web_view,
+                                                WebKitHitTestResult         *hit_test_result,
+                                                guint                        modifiers);
 
-    void (*_webkit_reserved0) (void);
-    void (*_webkit_reserved1) (void);
-    void (*_webkit_reserved2) (void);
-    void (*_webkit_reserved3) (void);
-    void (*_webkit_reserved4) (void);
-    void (*_webkit_reserved5) (void);
+
+    void       (* resource_load_started)       (WebKitWebView               *web_view,
+                                                WebKitWebResource           *resource,
+                                                WebKitURIRequest            *request);
+    gboolean   (* enter_fullscreen)            (WebKitWebView               *web_view);
+    gboolean   (* leave_fullscreen)            (WebKitWebView               *web_view);
+    gboolean   (* run_file_chooser)            (WebKitWebView               *web_view,
+                                                WebKitFileChooserRequest    *request);
+
+    gboolean   (* context_menu)                (WebKitWebView               *web_view,
+                                                WebKitContextMenu           *context_menu,
+                                                WebKitHitTestResult         *hit_test_result);
+
+    void       (* context_menu_dismissed)      (WebKitWebView               *web_view);
+    void       (* submit_form)                 (WebKitWebView               *web_view,
+                                                WebKitFormSubmissionRequest *request);
+    void       (* insecure_content_detected)   (WebKitWebView               *web_view,
+                                                WebKitInsecureContentEvent   event);
+    gboolean   (* web_process_crashed)         (WebKitWebView               *web_view);
+
+    gboolean   (* authenticate)                (WebKitWebView               *web_view,
+                                                WebKitAuthenticationRequest *request);
+    gboolean   (* load_failed_with_tls_errors) (WebKitWebView               *web_view,
+                                                const gchar                 *failing_uri,
+                                                GTlsCertificate             *certificate,
+                                                GTlsCertificateFlags         errors);
+    gboolean   (* show_notification)           (WebKitWebView               *web_view,
+                                                WebKitNotification          *notification);
+
+
+    void       (* web_process_terminated)      (WebKitWebView               *web_view,
+                                                WebKitWebProcessTerminationReason reason);
+    gboolean   (* user_message_received)       (WebKitWebView               *web_view,
+                                                WebKitUserMessage           *message);
+
+    gboolean   (* show_option_menu)            (WebKitWebView               *web_view,
+                                                WebKitOptionMenu            *menu,
+                                                WebKitRectangle             *rectangle);
+
+    gboolean   (* query_permission_state)      (WebKitWebView               *web_view,
+                                                WebKitPermissionStateQuery  *query);
+
+
+    /*< private >*/
+    void (*_webkit_reserved0)  (void);
+    void (*_webkit_reserved1)  (void);
+    void (*_webkit_reserved2)  (void);
+    void (*_webkit_reserved3)  (void);
+    void (*_webkit_reserved4)  (void);
+    void (*_webkit_reserved5)  (void);
+    void (*_webkit_reserved6)  (void);
+    void (*_webkit_reserved7)  (void);
+    void (*_webkit_reserved8)  (void);
+    void (*_webkit_reserved9)  (void);
+    void (*_webkit_reserved10) (void);
+    void (*_webkit_reserved11) (void);
+    void (*_webkit_reserved12) (void);
+    void (*_webkit_reserved13) (void);
+    void (*_webkit_reserved14) (void);
+    void (*_webkit_reserved15) (void);
+    void (*_webkit_reserved16) (void);
+    void (*_webkit_reserved17) (void);
+    void (*_webkit_reserved18) (void);
+    void (*_webkit_reserved19) (void);
+    void (*_webkit_reserved20) (void);
+    void (*_webkit_reserved21) (void);
+    void (*_webkit_reserved22) (void);
+    void (*_webkit_reserved23) (void);
+    void (*_webkit_reserved24) (void);
+    void (*_webkit_reserved25) (void);
+    void (*_webkit_reserved26) (void);
+    void (*_webkit_reserved27) (void);
+    void (*_webkit_reserved28) (void);
+    void (*_webkit_reserved29) (void);
+    void (*_webkit_reserved30) (void);
 };
 
-WEBKIT_API GType
-webkit_web_view_get_type                             (void);
 
 WEBKIT_API WebKitWebView *
 webkit_web_view_new                                  (WebKitWebViewBackend      *backend);
 
-WEBKIT_API WebKitWebView *
-webkit_web_view_new_with_context                     (WebKitWebViewBackend      *backend,
-                                                      WebKitWebContext          *context);
-
-WEBKIT_API WebKitWebView *
-webkit_web_view_new_with_settings                    (WebKitWebViewBackend      *backend,
-                                                      WebKitSettings            *settings);
-
-WEBKIT_API WebKitWebView *
-webkit_web_view_new_with_related_view                (WebKitWebViewBackend      *backend,
-                                                      WebKitWebView             *web_view);
-
-WEBKIT_API WebKitWebView *
-webkit_web_view_new_with_user_content_manager        (WebKitWebViewBackend      *backend,
-                                                      WebKitUserContentManager  *user_content_manager);
 
 WEBKIT_API WebKitWebViewBackend *
 webkit_web_view_get_backend                          (WebKitWebView             *web_view);
 
-WEBKIT_API gboolean
-webkit_web_view_is_ephemeral                         (WebKitWebView             *web_view);
+WEBKIT_API WPEDisplay *
+webkit_web_view_get_display                          (WebKitWebView             *web_view);
+
+WEBKIT_API WPEView *
+webkit_web_view_get_wpe_view                         (WebKitWebView             *web_view);
+
+WEBKIT_API void
+webkit_web_view_toggle_inspector                     (WebKitWebView             *web_view);
+
 
 WEBKIT_API gboolean
 webkit_web_view_is_controlled_by_automation          (WebKitWebView             *web_view);
@@ -294,8 +353,8 @@ webkit_web_view_is_controlled_by_automation          (WebKitWebView
 WEBKIT_API WebKitAutomationBrowsingContextPresentation
 webkit_web_view_get_automation_presentation_type     (WebKitWebView             *web_view);
 
-WEBKIT_API WebKitWebsiteDataManager *
-webkit_web_view_get_website_data_manager             (WebKitWebView             *web_view);
+WEBKIT_API WebKitNetworkSession *
+webkit_web_view_get_network_session                  (WebKitWebView             *web_view);
 
 WEBKIT_API WebKitWebContext *
 webkit_web_view_get_context                          (WebKitWebView             *web_view);
@@ -383,6 +442,7 @@ webkit_web_view_go_to_back_forward_list_item         (WebKitWebView
 WEBKIT_API const gchar *
 webkit_web_view_get_uri                              (WebKitWebView             *web_view);
 
+
 WEBKIT_API const gchar *
 webkit_web_view_get_custom_charset                   (WebKitWebView             *web_view);
 
@@ -430,44 +490,43 @@ webkit_web_view_execute_editing_command_with_argument(WebKitWebView
 WEBKIT_API WebKitFindController *
 webkit_web_view_get_find_controller                  (WebKitWebView             *web_view);
 
-WEBKIT_API void
-webkit_web_view_run_javascript                       (WebKitWebView             *web_view,
-                                                      const gchar               *script,
-                                                      GCancellable              *cancellable,
-                                                      GAsyncReadyCallback        callback,
-                                                      gpointer                   user_data);
-WEBKIT_API WebKitJavascriptResult *
-webkit_web_view_run_javascript_finish                (WebKitWebView             *web_view,
-                                                      GAsyncResult              *result,
-                                                      GError                   **error);
 
 WEBKIT_API void
-webkit_web_view_run_javascript_in_world              (WebKitWebView             *web_view,
-                                                      const gchar               *script,
-                                                      const gchar               *world_name,
-                                                      GCancellable              *cancellable,
-                                                      GAsyncReadyCallback        callback,
-                                                      gpointer                   user_data);
-WEBKIT_API WebKitJavascriptResult *
-webkit_web_view_run_javascript_in_world_finish       (WebKitWebView             *web_view,
-                                                      GAsyncResult              *result,
-                                                      GError                   **error);
-
-WEBKIT_API void
-webkit_web_view_run_javascript_from_gresource        (WebKitWebView             *web_view,
-                                                      const gchar               *resource,
+webkit_web_view_evaluate_javascript                  (WebKitWebView             *web_view,
+                                                      const char                *script,
+                                                      gssize                     length,
+                                                      const char                *world_name,
+                                                      const char                *source_uri,
                                                       GCancellable              *cancellable,
                                                       GAsyncReadyCallback        callback,
                                                       gpointer                   user_data);
 
-WEBKIT_API WebKitJavascriptResult *
-webkit_web_view_run_javascript_from_gresource_finish (WebKitWebView             *web_view,
+WEBKIT_API JSCValue *
+webkit_web_view_evaluate_javascript_finish           (WebKitWebView             *web_view,
                                                       GAsyncResult              *result,
                                                       GError                   **error);
 
+WEBKIT_API void
+webkit_web_view_call_async_javascript_function       (WebKitWebView             *web_view,
+                                                      const char                *body,
+                                                      gssize                     length,
+                                                      GVariant                  *arguments,
+                                                      const char                *world_name,
+                                                      const char                *source_uri,
+                                                      GCancellable              *cancellable,
+                                                      GAsyncReadyCallback        callback,
+                                                      gpointer                   user_data);
+
+WEBKIT_API JSCValue *
+webkit_web_view_call_async_javascript_function_finish(WebKitWebView             *web_view,
+                                                      GAsyncResult              *result,
+                                                      GError                   **error);
+
+
 WEBKIT_API WebKitWebResource *
 webkit_web_view_get_main_resource                    (WebKitWebView             *web_view);
 
+
 WEBKIT_API gboolean
 webkit_web_view_can_show_mime_type                   (WebKitWebView             *web_view,
                                                       const gchar               *mime_type);
@@ -506,9 +565,18 @@ webkit_web_view_get_tls_info                         (WebKitWebView
                                                       GTlsCertificate          **certificate,
                                                       GTlsCertificateFlags      *errors);
 
+
 WEBKIT_API WebKitUserContentManager *
 webkit_web_view_get_user_content_manager             (WebKitWebView             *web_view);
 
+
+WEBKIT_API void
+webkit_web_view_set_background_color                 (WebKitWebView               *web_view,
+                                                      WebKitColor                 *color);
+WEBKIT_API void
+webkit_web_view_get_background_color                 (WebKitWebView               *web_view,
+                                                      WebKitColor                 *color);
+
 WEBKIT_API gboolean
 webkit_web_view_is_editable                          (WebKitWebView             *web_view);
 
@@ -537,34 +605,139 @@ webkit_web_view_remove_frame_displayed_callback      (WebKitWebView
                                                       guint                        id);
 
 WEBKIT_API void
-webkit_web_view_set_background_color                 (WebKitWebView               *web_view,
-                                                      WebKitColor                 *color);
-WEBKIT_API void
-webkit_web_view_get_background_color                 (WebKitWebView               *web_view,
-                                                      WebKitColor                 *color);
-
-WEBKIT_API void
-webkit_web_view_send_message_to_page                 (WebKitWebView               *web_view,
-                                                      WebKitUserMessage           *message,
-                                                      GCancellable                *cancellable,
-                                                      GAsyncReadyCallback          callback,
-                                                      gpointer                     user_data);
+webkit_web_view_send_message_to_page                 (WebKitWebView             *web_view,
+                                                      WebKitUserMessage         *message,
+                                                      GCancellable              *cancellable,
+                                                      GAsyncReadyCallback        callback,
+                                                      gpointer                   user_data);
 
 WEBKIT_API WebKitUserMessage *
-webkit_web_view_send_message_to_page_finish          (WebKitWebView               *web_view,
-                                                      GAsyncResult                *result,
-                                                      GError                     **error);
+webkit_web_view_send_message_to_page_finish          (WebKitWebView             *web_view,
+                                                      GAsyncResult              *result,
+                                                      GError                   **error);
 
 WEBKIT_API void
-webkit_web_view_set_input_method_context             (WebKitWebView               *web_view,
-                                                      WebKitInputMethodContext    *context);
+webkit_web_view_set_input_method_context             (WebKitWebView             *web_view,
+                                                      WebKitInputMethodContext  *context);
 
 WEBKIT_API WebKitInputMethodContext *
-webkit_web_view_get_input_method_context             (WebKitWebView               *web_view);
+webkit_web_view_get_input_method_context             (WebKitWebView             *web_view);
+
+WEBKIT_API void
+webkit_web_view_set_cors_allowlist                   (WebKitWebView             *web_view,
+                                                      const gchar * const       *allowlist);
 
 WEBKIT_API WebKitWebsitePolicies *
 webkit_web_view_get_website_policies                 (WebKitWebView             *web_view);
 
+WEBKIT_API gboolean
+webkit_web_view_get_is_web_process_responsive        (WebKitWebView             *web_view);
+
+WEBKIT_API void
+webkit_web_view_terminate_web_process                (WebKitWebView             *web_view);
+
+WEBKIT_API WebKitMediaCaptureState
+webkit_web_view_get_camera_capture_state             (WebKitWebView             *web_view);
+
+WEBKIT_API void
+webkit_web_view_set_camera_capture_state             (WebKitWebView             *web_view,
+                                                      WebKitMediaCaptureState    state);
+
+WEBKIT_API WebKitMediaCaptureState
+webkit_web_view_get_microphone_capture_state         (WebKitWebView             *web_view);
+
+WEBKIT_API void
+webkit_web_view_set_microphone_capture_state         (WebKitWebView             *web_view,
+                                                      WebKitMediaCaptureState    state);
+
+WEBKIT_API WebKitMediaCaptureState
+webkit_web_view_get_display_capture_state            (WebKitWebView             *web_view);
+
+WEBKIT_API void
+webkit_web_view_set_display_capture_state            (WebKitWebView             *web_view,
+                                                      WebKitMediaCaptureState    state);
+
+WEBKIT_API WebKitWebExtensionMode
+webkit_web_view_get_web_extension_mode               (WebKitWebView             *web_view);
+
+WEBKIT_API const gchar*
+webkit_web_view_get_default_content_security_policy  (WebKitWebView             *web_view);
+
+WEBKIT_API gboolean
+webkit_web_view_get_theme_color                      (WebKitWebView             *web_view,
+                                                      WebKitColor               *color);
+
+
+/**
+ * webkit_web_view_run_async_javascript_function_in_world: (finish-func webkit_web_view_run_javascript_in_world_finish)
+ * @web_view: a #WebKitWebView
+ * @body: the JavaScript function body
+ * @arguments: a #GVariant with format `{&sv}` storing the function arguments. Function argument values must be one of the following types, or contain only the following GVariant types: number, string, array, and dictionary.
+ * @world_name: (nullable): the name of a #WebKitScriptWorld, if no name (i.e. %NULL) is provided, the default world is used. Any value that is not %NULL is a distinct world.
+ * @cancellable: (allow-none): a #GCancellable or %NULL to ignore
+ * @callback: (scope async): a #GAsyncReadyCallback to call when the script finished
+ * @user_data: the data to pass to callback function
+ *
+ * Asynchronously run @body in the script world with name @world_name of the current page context in
+ * @web_view. If WebKitSettings:enable-javascript is FALSE, this method will do nothing. This API
+ * differs from webkit_web_view_run_javascript_in_world() in that the JavaScript function can return a
+ * Promise and its result will be properly passed to the callback.
+ *
+ * When the operation is finished, @callback will be called. You can then call
+ * webkit_web_view_run_javascript_in_world_finish() to get the result of the operation.
+ *
+ * For instance here is a dummy example that shows how to pass arguments to a JS function that
+ * returns a Promise that resolves with the passed argument:
+ *
+ * ```c
+ * static void
+ * web_view_javascript_finished (GObject      *object,
+ *                               GAsyncResult *result,
+ *                               gpointer      user_data)
+ * {
+ *     WebKitJavascriptResult *js_result;
+ *     JSCValue               *value;
+ *     GError                 *error = NULL;
+ *
+ *     js_result = webkit_web_view_run_javascript_finish (WEBKIT_WEB_VIEW (object), result, &error);
+ *     if (!js_result) {
+ *         g_warning ("Error running javascript: %s", error->message);
+ *         g_error_free (error);
+ *         return;
+ *     }
+ *
+ *     value = webkit_javascript_result_get_js_value (js_result);
+ *     if (jsc_value_is_number (value)) {
+ *         gint32        int_value = jsc_value_to_string (value);
+ *         JSCException *exception = jsc_context_get_exception (jsc_value_get_context (value));
+ *         if (exception)
+ *             g_warning ("Error running javascript: %s", jsc_exception_get_message (exception));
+ *         else
+ *             g_print ("Script result: %d\n", int_value);
+ *         g_free (str_value);
+ *     } else {
+ *         g_warning ("Error running javascript: unexpected return value");
+ *     }
+ *     webkit_javascript_result_unref (js_result);
+ * }
+ *
+ * static void
+ * web_view_evaluate_promise (WebKitWebView *web_view)
+ * {
+ *     GVariantDict dict;
+ *     g_variant_dict_init (&dict, NULL);
+ *     g_variant_dict_insert (&dict, "count", "u", 42);
+ *     GVariant *args = g_variant_dict_end (&dict);
+ *     const gchar *body = "return new Promise((resolve) => { resolve(count); });";
+ *     webkit_web_view_run_async_javascript_function_in_world (web_view, body, arguments, NULL, NULL, web_view_javascript_finished, NULL);
+ * }
+ * ```
+ *
+ * Since: 2.38
+ *
+ * Deprecated: 2.40: Use webkit_web_view_call_async_javascript_function() instead.
+ */
+
 G_END_DECLS
 
 #endif
